@@ -4,7 +4,7 @@ from typing import List
 
 from pydantic import BaseModel
 
-from botx.models.mentions import Mention
+from botx.models.entities import Mention
 from botx.models.typing import AvailableRecipients
 
 
@@ -27,7 +27,7 @@ class MessageOptions(BaseModel):
     #: attached to message mentions.
     mentions: List[Mention] = []
 
-    #: don't show next user messages in chat
+    #: if true don't show next user's input in chat
     silent_response: bool = False
 
     #: notification configuration.
